@@ -1,16 +1,30 @@
 # -*- coding: utf-8 -*-
 
+# DATABASES = {
+#     'default': {
+#         'ENGINE': 'django.db.backends.postgresql_psycopg2',
+#         'NAME': 'lojaintegrada',
+#         'USER': 'lojaintegrada',
+#         'PASSWORD': 'lojaintegrada',
+#         'HOST': 'localhost',
+#         'PORT': '5432',
+#     }
+# }
+
+
+#na VTEX
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.postgresql_psycopg2',
         'NAME': 'lojaintegrada',
         'USER': 'lojaintegrada',
-        'PASSWORD': 'lojaintegrada',
-        'HOST': 'localhost',
+        'PASSWORD': '123321',
+        'HOST': '10.1.13.244',
         'PORT': '5432',
     }
 }
 
+
 DEBUG = True
 
 INSTALLED_APPS = (
